@@ -237,6 +237,9 @@ class TestBasics:
 
 
 class TestPerformance:
+    @pytest.mark.skipif(
+        path.PY2,
+        reason="Tests fail frequently on Python 2; see #153")
     def test_import_time(self, monkeypatch):
         """
         Import of path.py should take less than 100ms.
@@ -409,10 +412,6 @@ class TestScratchDir:
                 except Exception:
                     pass
 
-    @pytest.mark.xfail(
-        platform.system() == 'Linux' and path.PY2,
-        reason="Can't decode bytes in FS. See #121",
-    )
     @pytest.mark.xfail(
         mac_version('10.13'),
         reason="macOS disallows invalid encodings",
@@ -855,6 +854,20 @@ class TestMergeTree:
         assert self.subdir_b.isdir()
         assert self.subdir_b.listdir() == [self.subdir_b / self.test_file.name]
 
+    def test_only_newer(self):
+        """
+        merge_tree should accept a copy_function in which only
+        newer files are copied and older files do not overwrite
+        newer copies in the dest.
+        """
+        target = self.subdir_b / 'testfile.txt'
+        target.write_text('this is newer')
+        self.subdir_a.merge_tree(
+            self.subdir_b,
+            copy_function=path.only_newer(shutil.copy2),
+        )
+        assert target.text() == 'this is newer'
+
 
 class TestChdir:
     def test_chdir_or_cd(self, tmpdir):
@@ -1235,3 +1248,11 @@ def test_no_dependencies():
         '-c', 'import path',
     ]
     subprocess.check_call(cmd)
+
+
+def test_version():
+    """
+    Under normal circumstances, path should present a
+    __version__.
+    """
+    assert re.match(r'\d+\.\d+.*', path.__version__)
